bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.has_plotter
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.has_plotter